<?php
/**
 * The loop that displays posts.
 *
 * The loop displays the posts and the post content.  See
 * http://codex.wordpress.org/The_Loop to understand it and
 * http://codex.wordpress.org/Template_Tags to understand
 * the tags used in it.
 *
 * This can be overridden in child themes with loop.php or
 * loop-template.php, where 'template' is the loop context
 * requested by a template. For example, loop-index.php would
 * be used if it exists and we ask for the loop with:
 * <code>get_template_part( 'loop', 'index' );</code>
 *
 * @package WordPress
 * @subpackage Twenty_Ten
 * @since Twenty Ten 1.0
 */
?>

<div id="content">

<?php /* If there are no posts to display, such as an empty archive page */ ?>
<?php if ( ! have_posts() ) : ?>
	<div id="post-0" class="post error404 not-found">
		<h1 class="post-title"><?php _e( 'Not Found', 'android' ); ?></h1>
		<div class="post-content">
			<p><?php _e( 'Apologies, but no results were found for the requested archive. Perhaps searching will help find a related post.', 'android' ); ?></p>
			<?php get_search_form(); ?>

		</div><!-- .post-content -->
	</div><!-- #post-0 -->
<?php endif; ?>

<?php
	/* Start the Loop.
	 *
	 * In Twenty Ten we use the same loop in multiple contexts.
	 * It is broken into three main parts: when we're displaying
	 * posts that are in the gallery category, when we're displaying
	 * posts in the asides category, and finally all other posts.
	 *
	 * Additionally, we sometimes check for whether we are on an
	 * archive page, a search page, etc., allowing for small differences
	 * in the loop on each template without actually duplicating
	 * the rest of the loop that is shared.
	 *
	 * Without further ado, the loop:
	 */ ?>
<?php while ( have_posts() ) : the_post(); ?>

		<div id="post-<?php the_ID(); ?>" <?php post_class((get_option('android_use_thubmnails')&&has_post_thumbnail()?' has-thumbnail':'')); ?>>
			<h2 class="post-title"><a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'android' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title(); ?></a></h2>
			
			<div class="post-wrap">
			
			<?php if( get_option('android_use_thubmnails') && has_post_thumbnail() ) {
				?><div class="post-thumbnail"><a href="<?php echo esc_attr(get_permalink()); ?>" title="<?php the_title_attribute(); ?>"><?php
				the_post_thumbnail();
				?></a></div><?php
			} ?>


			<div class="meta post-date">
				<?php android_posted_on(); ?>
			</div><!-- .post-meta -->

			<br class="clear" />
			
	<?php if ( is_archive() || is_search() ) : // Only display excerpts for archives and search. ?>
			<div class="post-summary">
				<?php the_excerpt(); ?>
			</div><!-- .post-summary -->
	<?php else : ?>
			<div class="post-content">
				<?php the_content( __( 'Keep reading &rarr;', 'android' ) ); ?>
				<?php wp_link_pages( array( 'before' => '<div class="page-link">' . __( 'Pages:', 'android' ), 'after' => '</div>' ) ); ?>

			</div><!-- .post-content -->
	<?php endif; ?>


			<br class="clear" />

			<div class="post-meta">
					<?php android_post_meta(); ?>

			</div><!-- .post-meta -->
			
			<br class="clear" />
			
			</div>
		</div><!-- #post-## -->

<?php endwhile; // End the loop. Whew. ?>

<?php /* Display navigation to next/previous pages when applicable */
if( function_exists( 'wp_pagenavi' ) ) {
	wp_pagenavi();
} elseif ( $wp_query->max_num_pages > 1 ) { ?>
				<div id="nav-below" class="navigation">
					<div class="older"><?php next_posts_link( __( '&larr; Older posts', 'android' ) ); ?></div>
					<div class="newer"><?php previous_posts_link( __( 'Newer posts &rarr;', 'android' ) ); ?></div>
				</div><!-- #nav-below -->
<?php } ?>

</div>
